@@ -81,9 +81,9 @@ class Config(metaclass=Singleton):
                 {"name": "Setters", "code": "P2", "make": lambda: P2()},
                 {"name": "Empty Rethrow", "code": "P3", "make": lambda: P3()},
                 {"name": "Prohibited class name", "code": "P4", "make": lambda: P4()},
-                {"name": "Force Type Casting Finder", "code": "P5", "make": lambda: P5()},
+                {"name": "Force Type Casting", "code": "P5", "make": lambda: P5()},
                 {"name": "Count If Return", "code": "P6", "make": lambda: P6()},
-                {"name": "Implements Multi Finder", "code": "P7", "make": lambda: P7()},
+                {"name": "Implements Multi", "code": "P7", "make": lambda: P7()},
                 {"name": "Instance of", "code": "P8", "make": lambda: P8()},
                 {"name": "Many primary constructors", "code": "P9", "make": lambda: P9()},
                 {"name": "Method chain", "code": "P10", "make": lambda: P10()},
@@ -93,9 +93,9 @@ class Config(metaclass=Singleton):
                 {"name": "Partial synchronized", "code": "P14", "make": lambda: P14()},
                 {"name": "Redundant catch", "code": "P15", "make": lambda: P15()},
                 {"name": "Return null", "code": "P16", "make": lambda: P16()},
-                {"name": "String concat finder", "code": "P17", "make": lambda: P17()},
+                {"name": "String concat", "code": "P17", "make": lambda: P17()},
                 {"name": "Super Method", "code": "P18", "make": lambda: P18()},
-                {"name": "This finder", "code": "P19", "make": lambda: P19()},
+                {"name": "This in constructor", "code": "P19", "make": lambda: P19()},
                 {
                     "name": "Var declaration distance for 5 lines",
                     "code": "P20_5",
