@@ -12,13 +12,14 @@ class newJavalangImproved(JavalangImproved):
                 if type(i.node.then_statement) in [javalang.tree.BlockStatement] and i.node.else_statement is not None:
                     for check_return in i.node.then_statement.statements:
                         if type(check_return) in [javalang.tree.ReturnStatement]:
-                            array.append(nodes[index].line + 1)
+                            array.append(nodes[index].line)
         return array
 
 
 class CountIfReturn:
     '''
-    Returns lines with if statement which has also returb statement and other conditions with else.
+    Returns lines with if statement which has also return statement
+    and other conditions with else.
     '''
     def __init__(self):
         pass
