@@ -9,4 +9,8 @@ class PublicStaticMethod:
 
     def value(self, filename: str):
         tree = AST(filename).value().filter(javalang.tree.MethodDeclaration)
-        return [node for path, node in tree if all(elem in node.modifiers for elem in ['public', 'static'])]
+        return [
+            node.position.line for
+            path, node in tree if
+            all(elem in node.modifiers for elem in ['public', 'static'])
+        ]
